@@ -139,14 +139,18 @@ class XML(object):
 
         return parsed
 
-    @staticmethod
-    def __xml_encode(row):
+    def __xml_encode(self, row):
         xmlitem = ['  <record>']
 
         for field in row.index:
             if row[field]:
-                xmlitem.append('    <var var_name="{0}">{1}</var>'.format(field, row[field]))
+                xmlitem.append('    <var var_name="{0}">{1}</var>'.format(field, self.__handle_illegals(row[field])))
 
         xmlitem.append('  </record>')
 
         return '\n'.join(xmlitem)
+
+    @staticmethod
+    def __handle_illegals(data):
+        return data.replace('<', '&lt;').replace('>', '&gt;').replace('&', '&amp;').replace('"', '&quot;') \
+            .replace("'", '&apos;')
